/*
 * Copyright (C) 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

public class Main {
    public static void main(String[] args) {
        Clinit.run();
        if (!clinitDidRun) {
            throw new Error("Expected Clinit.<clinit> to have run");
        }
    }
    static boolean clinitDidRun = false;
}

class Clinit {
    public static void run() {}

    static {
        Main.clinitDidRun = true;
    }
}
